import {Component, Host, h, Prop, Watch, State, Listen} from '@stencil/core';

export interface AnchorItem {
  title: string;
  url: string;
}

@Component({
  tag: 'hy-anchor-link-list',
  styleUrl: 'hy-anchor-link-list.scss',
  shadow: true,
})
export class HyAnchorLinkList {
  private _anchorItems: AnchorItem[];

  /**
   * Title for content list button
   */
  @Prop() listTitle?: string;
  /**
   * Open state label
   */
  @Prop() openLabel?: string;
  /**
   * Close state label
   */
  @Prop() closeLabel?: string;
  /**
   * Array of anchor items
   */
  @Prop() anchorItems: AnchorItem[] | string;

  @State() isOpen: boolean = false;

  @Watch('anchorItems') anchorItemsWatcher(data: AnchorItem[] | string) {
    this._anchorItems = typeof data === 'string' ? JSON.parse(data) : data;
  }

  componentWillLoad() {
    this.anchorItemsWatcher(this.anchorItems);
  }

  @Listen('handleLinkClick')
  handleLinkClick(e) {
    const targetId = e.target.getAttribute('href');
    if (targetId) {
      const targetElement = document.getElementById(targetId.substring(1));
      const targetRect = targetElement.getBoundingClientRect();
      window.scrollTo({top: window.scrollY + targetRect.top - 100, behavior: 'smooth'});
    }
    e.preventDefault();
    e.stopPropagation();
  }

  render() {
    const classAttributes = ['hy-anchor-link-list'].join(' ');
    const buttonClasses = {
      'hy-anchor-link-list__button': true,
      'is-open': this.isOpen,
    };
    const containerClasses = {
      'hy-anchor-link-list__container': true,
      'is-open': this.isOpen,
    };
    const items = this._anchorItems as Array<AnchorItem>;

    return (
      <Host class={classAttributes}>
        <button aria-label={this.listTitle} onClick={() => (this.isOpen = !this.isOpen)} class={buttonClasses}>
          <span class="hy-anchor-link-list__button--title">
            <hy-icon icon={'hy-icon-bullet-list'} size={18} fill={'var(--brand-main)'} />
            {this.listTitle}
          </span>
          <span class="hy-anchor-link-list__button--label">
            {this.isOpen ? this.closeLabel : this.openLabel}
            <hy-icon class="label-close-icon" icon={'hy-icon-caret-down'} size={16} fill={'var(--brand-main)'} />
          </span>
        </button>
        <div aria-hidden={this.isOpen ? 'false' : 'true'} class={containerClasses}>
          {items &&
            items.map((item) => (
              <a class="hy-anchor-link-list__item" href={item.url} onClick={this.handleLinkClick}>
                <hy-icon icon={'hy-icon-arrow-down'} size={12} fill={'var(--brand-main)'} />
                {item.title}
              </a>
            ))}
        </div>
      </Host>
    );
  }
}
